----------------------------------------------------
Additional modules
----------------------------------------------------

Full power of Ralph comes with:

* Ralph Pricing("Scrooge") https://github.com/allegro/ralph_pricing
* Ralph Assets https://github.com/allegro/ralph_assets/

In order for ralph to include them, you need to add them to your configuration
like this::

    PLUGGABLE_APPS = ['scrooge', 'assets']
